==> jcusparse-10.1.1-sources.jar: jcuda/jcusparse/cusparseFormat.java <==
/*
 * JCusparse - Java bindings for CUSPARSE, the NVIDIA CUDA sparse
 * matrix library, to be used with JCuda
 *
 * Copyright (c) 2010-2016 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcusparse;

//==============================================================================
//==============================================================================
// #############
// # SpMM APIs #
// #############
public class cusparseFormat
{
    public static final int CUSPARSE_FORMAT_CSR = 1;
    public static final int CUSPARSE_FORMAT_CSC = 2;
    public static final int CUSPARSE_FORMAT_COO = 3;

    /**
     * Private constructor to prevent instantiation
     */
    private cusparseFormat()
    {
        // Private constructor to prevent instantiation
    }

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUSPARSE_FORMAT_CSR: return "CUSPARSE_FORMAT_CSR";
            case CUSPARSE_FORMAT_CSC: return "CUSPARSE_FORMAT_CSC";
            case CUSPARSE_FORMAT_COO: return "CUSPARSE_FORMAT_COO";
        }
        return "INVALID cusparseFormat: "+n;
    }
}

==> jcusparse-11.7.0-sources.jar: jcuda/jcusparse/cusparseFormat.java <==
/*
 * JCusparse - Java bindings for CUSPARSE, the NVIDIA CUDA sparse
 * matrix library, to be used with JCuda
 *
 * Copyright (c) 2010-2016 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jcusparse;

public class cusparseFormat
{
    /**
     * Compressed Sparse Row (CSR)
     */
    public static final int CUSPARSE_FORMAT_CSR = 1;
    /**
     * Compressed Sparse Column (CSC)
     */
    public static final int CUSPARSE_FORMAT_CSC = 2;
    /**
     * Coordinate (COO) - Structure of Arrays
     */
    public static final int CUSPARSE_FORMAT_COO = 3;
    /**
     * Coordinate (COO) - Array of Structures
     */
    public static final int CUSPARSE_FORMAT_COO_AOS = 4;

    /**
     * Private constructor to prevent instantiation
     */
    private cusparseFormat()
    {
        // Private constructor to prevent instantiation
    }

    /**
     * Returns a string representation of the given constant
     *
     * @return A string representation of the given constant
     */
    public static String stringFor(int n)
    {
        switch (n)
        {
            case CUSPARSE_FORMAT_CSR: return "CUSPARSE_FORMAT_CSR";
            case CUSPARSE_FORMAT_CSC: return "CUSPARSE_FORMAT_CSC";
            case CUSPARSE_FORMAT_COO: return "CUSPARSE_FORMAT_COO";
            case CUSPARSE_FORMAT_COO_AOS: return "CUSPARSE_FORMAT_COO_AOS";
        }
        return "INVALID cusparseFormat: "+n;
    }
}
